@@ -1,6 +1,6 @@
 package Dancer::Plugin::Email;
 
-our $VERSION = '1.0300'; # VERSION
+our $VERSION = '1.0400'; # VERSION
 
 use Dancer qw(:syntax debug warning);
 use Dancer::Plugin;
@@ -47,12 +47,14 @@ register email => sub {
             my %mime;
             if (ref($attachment) eq 'HASH') {
                 %mime = %$attachment;
-                unless ($mime{Path}) {
-                    warning "No Path provided for this attachment!";
+                unless ($mime{Path} || $mime{Data}) {
+                    warning "No Path or Data provided for this attachment!";
                     next;
                 };
-                $mime{Encoding} ||= 'base64';
-                $mime{Type} ||= File::Type->mime_type($mime{Path}),
+                if ($mime{Path}) {
+                    $mime{Encoding} ||= 'base64';
+                    $mime{Type} ||= File::Type->mime_type($mime{Path});
+                }
             } else {
                 %mime = (
                     Path     => $attachment,
@@ -112,7 +114,7 @@ Dancer::Plugin::Email - Simple email sending for Dancer applications
 
 =head1 VERSION
 
-version 1.0300
+version 1.0400
 
 =head1 SYNOPSIS
 
@@ -281,6 +283,11 @@ Example:
          multipart => 'related'
         };
 
+The C<attach> value accepts either a single attachment or an arrayref
+of attachment. Each attachment may be a scalar, with the path of the
+file to attach, or an hashref, in which case the hashref is passed to
+the L<Mime::Entity>'s C<attach> method.
+
 =head1 CONTRIBUTORS
 
 =over
